==> qtcreator_4.14.1.orig.tar.xz: qt-creator-opensource-src-4.14.1/src/plugins/mesonprojectmanager/settings/tools/toolssettingsaccessor.h <==
/****************************************************************************
**
** Copyright (C) 2020 Alexis Jeandet.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once
#include "utils/settingsaccessor.h"
#include <exewrappers/mesontools.h>

namespace MesonProjectManager {
namespace Internal {

class ToolsSettingsAccessor final : public Utils::UpgradingSettingsAccessor
{
public:
    ToolsSettingsAccessor();
    void saveMesonTools(const std::vector<MesonTools::Tool_t> &tools, QWidget *parent);
    std::vector<MesonTools::Tool_t> loadMesonTools(QWidget *parent);
};

} // namespace Internal
} // namespace MesonProjectManager

==> qtcreator_6.0.2.orig.tar.xz: qt-creator-opensource-src-6.0.2/src/plugins/mesonprojectmanager/settings/tools/toolssettingsaccessor.h <==
/****************************************************************************
**
** Copyright (C) 2020 Alexis Jeandet.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "exewrappers/mesontools.h"

#include <utils/settingsaccessor.h>

namespace MesonProjectManager {
namespace Internal {

class ToolsSettingsAccessor final : public Utils::UpgradingSettingsAccessor
{
public:
    ToolsSettingsAccessor();
    void saveMesonTools(const std::vector<MesonTools::Tool_t> &tools, QWidget *parent);
    std::vector<MesonTools::Tool_t> loadMesonTools(QWidget *parent);
};

} // namespace Internal
} // namespace MesonProjectManager
